@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.009001';
+$MetaCPAN::Client::VERSION = '2.010000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
@@ -19,6 +19,7 @@ use MetaCPAN::Client::Pod;
 use MetaCPAN::Client::Rating;
 use MetaCPAN::Client::Release;
 use MetaCPAN::Client::Mirror;
+use MetaCPAN::Client::Permission;
 use MetaCPAN::Client::ResultSet;
 
 has request => (
@@ -27,7 +28,7 @@ has request => (
 );
 
 my @supported_searches = qw<
-    author distribution favorite module rating release mirror file
+    author distribution favorite module rating release mirror file permission
 >;
 
 sub BUILDARGS {
@@ -74,6 +75,14 @@ sub file {
     return $self->_get_or_search( 'file', $arg, $params );
 }
 
+sub permission {
+    my $self   = shift;
+    my $arg    = shift;
+    my $params = shift;
+
+    return $self->_get_or_search( 'permission', $arg, $params );
+}
+
 sub pod {
     my $self   = shift;
     my $name   = shift;
@@ -372,7 +381,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.009001
+version 2.010000
 
 =head1 SYNOPSIS
 
@@ -508,6 +517,12 @@ L<MetaCPAN::Client::Release> objects on a complex (L<search spec based|/"SEARCH
 
 Returns a L<MetaCPAN::Client::Mirror> object.
 
+=head2 permission
+
+    my $permission = $mcpan->permission('MooseX::Types');
+
+Returns a L<MetaCPAN::Client::Permission> object.
+
 =head2 reverse_dependencies
 
     my $deps = $mcpan->reverse_dependencies('ElasticSearch');
