@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Module;
 # ABSTRACT: A Module data object
-$MetaCPAN::Client::Module::VERSION = '2.009001';
+$MetaCPAN::Client::Module::VERSION = '2.010000';
 use Moo;
 extends 'MetaCPAN::Client::File';
 
@@ -12,6 +12,11 @@ sub metacpan_url {
             $self->author, $self->release, $self->path );
 }
 
+sub permission {
+    my $self = shift;
+    return $self->client->permission( $self->documentation );
+}
+
 1;
 
 __END__
@@ -26,7 +31,7 @@ MetaCPAN::Client::Module - A Module data object
 
 =head1 VERSION
 
-version 2.009001
+version 2.010000
 
 =head1 SYNOPSIS
 
@@ -48,6 +53,10 @@ Whatever L<MetaCPAN::Client::File> has.
 
 Returns a link to the module page on MetaCPAN.
 
+=head2 permission
+
+Returns an L<MetaCPAN::Client::Permission> object for the module.
+
 =head1 AUTHORS
 
 =over 4
